@@ -1,41 +1,26 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::2_0::Direct;
-
+package Search::Elasticsearch::Client::5_0::Direct;
+$Search::Elasticsearch::Client::5_0::Direct::VERSION = '6.00';
 use Moo;
-with 'Search::Elasticsearch::Client::2_0::Role::API';
+with 'Search::Elasticsearch::Client::5_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 
-our $VERSION='7.30_1';
-use Search::Elasticsearch 7.00 ();
-
 use Search::Elasticsearch::Util qw(parse_params is_compat);
 use namespace::clean;
 
 sub _namespace {__PACKAGE__}
 
-has 'cluster'             => ( is => 'lazy', init_arg => undef );
-has 'nodes'               => ( is => 'lazy', init_arg => undef );
-has 'indices'             => ( is => 'lazy', init_arg => undef );
-has 'snapshot'            => ( is => 'lazy', init_arg => undef );
-has 'cat'                 => ( is => 'lazy', init_arg => undef );
-has 'tasks'               => ( is => 'lazy', init_arg => undef );
+has 'cluster'  => ( is => 'lazy', init_arg => undef );
+has 'nodes'    => ( is => 'lazy', init_arg => undef );
+has 'indices'  => ( is => 'lazy', init_arg => undef );
+has 'ingest'   => ( is => 'lazy', init_arg => undef );
+has 'snapshot' => ( is => 'lazy', init_arg => undef );
+has 'cat'      => ( is => 'lazy', init_arg => undef );
+has 'tasks'    => ( is => 'lazy', init_arg => undef );
 has 'bulk_helper_class'   => ( is => 'rw' );
 has 'scroll_helper_class' => ( is => 'rw' );
 has '_bulk_class'         => ( is => 'lazy' );
 has '_scroll_class'       => ( is => 'lazy' );
 
-#===================================
-sub create {
-#===================================
-    my ( $self, $params ) = parse_params(@_);
-    my $defn = $self->api->{index};
-    $params->{op_type} = 'create';
-    $self->perform_request( { %$defn, name => 'create' }, $params );
-}
-
 #===================================
 sub _build__bulk_class {
 #===================================
@@ -74,6 +59,7 @@ sub scroll_helper {
 sub _build_cluster  { shift->_build_namespace('Cluster') }
 sub _build_nodes    { shift->_build_namespace('Nodes') }
 sub _build_indices  { shift->_build_namespace('Indices') }
+sub _build_ingest   { shift->_build_namespace('Ingest') }
 sub _build_snapshot { shift->_build_namespace('Snapshot') }
 sub _build_cat      { shift->_build_namespace('Cat') }
 sub _build_tasks    { shift->_build_namespace('Tasks') }
@@ -89,11 +75,11 @@ __PACKAGE__->_install_api('');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::2_0::Direct - Thin client with full support for Elasticsearch 2.x APIs
+Search::Elasticsearch::Client::5_0::Direct - Thin client with full support for Elasticsearch 5.x APIs
 
 =head1 VERSION
 
-version 7.30_1
+version 6.00
 
 =head1 SYNOPSIS
 
@@ -101,7 +87,7 @@ Create a client:
 
     use Search::Elasticsearch;
     my $e = Search::Elasticsearch->new(
-        client => '2_0::Direct'
+        client => '5_0::Direct'
     );
 
 Index a doc:
@@ -143,6 +129,10 @@ Index-level requests:
     $e->indices->create( index => 'my_index' );
     $e->indices->delete( index => 'my_index' )
 
+Ingest pipeline requests:
+
+    $e->ingest->get_pipeline( id => 'apache-logs' );
+
 Cluster-level requests:
 
     $health = $e->cluster->health;
@@ -178,11 +168,11 @@ Task management:
 
 =head1 DESCRIPTION
 
-The L<Search::Elasticsearch::Client::2_0::Direct> class provides the
-Elasticsearch 2.x compatible client returned by:
+The L<Search::Elasticsearch::Client::5_0::Direct> class provides the
+Elasticsearch 5.x compatible client returned by:
 
     $e = Search::Elasticsearch->new(
-        client => "2_0::Direct"
+        client => "5_0::Direct"  # default
     );
 
 It is intended to be as close as possible to the native REST API that
@@ -195,6 +185,30 @@ L<bulk document CRUD|/BULK DOCUMENT CRUD METHODS> and L<search|/SEARCH METHODS>.
 It also provides access to clients for managing L<indices|/indices()>
 and the L<cluster|/cluster()>.
 
+=head1 PREVIOUS VERSIONS OF ELASTICSEARCH
+
+This version of the client supports the Elasticsearch 5.0 branch,
+which is not backwards compatible with earlier branches.
+
+If you need to talk to a version of Elasticsearch before 5.0.0, please
+install one of the following modules:
+
+=over
+
+=item *
+
+L<Search::Elasticsearch::Client::2_0>
+
+=item *
+
+L<Search::Elasticsearch::Client::1_0>
+
+=item *
+
+L<Search::Elasticsearch::Client::0_90>
+
+=back
+
 =head1 CONVENTIONS
 
 =head2 Parameter passing
@@ -288,12 +302,12 @@ Multiple error codes can be specified with an array:
 =head2 C<bulk_helper_class>
 
 The class to use for the L</bulk_helper()> method. Defaults to
-L<Search::Elasticsearch::Client::2_0::Bulk>.
+L<Search::Elasticsearch::Client::5_0::Bulk>.
 
 =head2 C<scroll_helper_class>
 
 The class to use for the L</scroll_helper()> method. Defaults to
-L<Search::Elasticsearch::Client::2_0::Scroll>.
+L<Search::Elasticsearch::Client::5_0::Scroll>.
 
 =head1 GENERAL METHODS
 
@@ -315,29 +329,36 @@ response, otherwise it throws an error.
 
     $indices_client = $e->indices;
 
-Returns an L<Search::Elasticsearch::Client::2_0::Direct::Indices> object which can be used
+Returns a L<Search::Elasticsearch::Client::5_0::Direct::Indices> object which can be used
 for managing indices, eg creating, deleting indices, managing mapping,
 index settings etc.
 
+=head2 C<ingest()>
+
+    $ingest_client = $e->ingest;
+
+Returns a L<Search::Elasticsearch::Client::5_0::Direct::Ingest> object which can be used
+for managing ingest pipelines.
+
 =head2 C<cluster()>
 
     $cluster_client = $e->cluster;
 
-Returns an L<Search::Elasticsearch::Client::2_0::Direct::Cluster> object which can be used
+Returns a L<Search::Elasticsearch::Client::5_0::Direct::Cluster> object which can be used
 for managing the cluster, eg cluster-wide settings and cluster health.
 
 =head2 C<nodes()>
 
     $node_client = $e->nodes;
 
-Returns an L<Search::Elasticsearch::Client::2_0::Direct::Nodes> object which can be used
+Returns a L<Search::Elasticsearch::Client::5_0::Direct::Nodes> object which can be used
 to retrieve node info and stats.
 
 =head2 C<snapshot()>
 
     $snapshot_client = $e->snapshot;
 
-Returns an L<Search::Elasticsearch::Client::2_0::Direct::Snapshot> object which
+Returns a L<Search::Elasticsearch::Client::5_0::Direct::Snapshot> object which
 is used for managing backup repositories and creating and restoring
 snapshots.
 
@@ -345,14 +366,14 @@ snapshots.
 
     $tasks_client = $e->tasks;
 
-Returns an L<Search::Elasticsearch::Client::2_0::Direct::Tasks> object which
+Returns a L<Search::Elasticsearch::Client::5_0::Direct::Tasks> object which
 is used for accessing the task management API.
 
 =head2 C<cat()>
 
     $cat_client = $e->cat;
 
-Returns an L<Search::Elasticsearch::Client::2_0::Direct::Cat> object which can be used
+Returns a L<Search::Elasticsearch::Client::5_0::Direct::Cat> object which can be used
 to retrieve simple to read text info for debugging and monitoring an
 Elasticsearch cluster.
 
@@ -375,16 +396,19 @@ The C<index()> method is used to index a new document or to reindex
 an existing document.
 
 Query string parameters:
-    C<consistency>,
+    C<error_trace>,
+    C<human>,
     C<op_type>,
     C<parent>,
+    C<pipeline>,
     C<refresh>,
     C<routing>,
     C<timeout>,
     C<timestamp>,
     C<ttl>,
     C<version>,
-    C<version_type>
+    C<version_type>,
+    C<wait_for_active_shards>
 
 See the L<index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/docs-index_.html>
 for more information.
@@ -394,7 +418,7 @@ for more information.
     $response = $e->create(
         index   => 'index_name',        # required
         type    => 'type_name',         # required
-        id      => 'doc_id',            # optional, otherwise auto-generated
+        id      => 'doc_id',            # required
 
         body    => { document }         # required
     );
@@ -405,6 +429,8 @@ C<index>, C<type> and C<id> already exists.
 
 Query string parameters:
     C<consistency>,
+    C<error_trace>,
+    C<human>,
     C<op_type>,
     C<parent>,
     C<refresh>,
@@ -433,12 +459,14 @@ Query string parameters:
     C<_source>,
     C<_source_exclude>,
     C<_source_include>,
-    C<fields>,
+    C<error_trace>,
+    C<human>,
     C<parent>,
     C<preference>,
     C<realtime>,
     C<refresh>,
     C<routing>,
+    C<stored_fields>,
     C<version>,
     C<version_type>
 
@@ -462,6 +490,8 @@ Query string parameters:
     C<_source>,
     C<_source_exclude>,
     C<_source_include>,
+    C<error_trace>,
+    C<human>,
     C<parent>,
     C<preference>,
     C<realtime>,
@@ -485,11 +515,18 @@ The C<exists()> method returns C<1> if a document with the specified
 C<index>, C<type> and C<id> exists, or an empty string if it doesn't.
 
 Query string parameters:
+    C<_source>,
+    C<_source_exclude>,
+    C<_source_include>,
+    C<error_trace>,
+    C<human>,
     C<parent>,
     C<preference>,
     C<realtime>,
     C<refresh>,
-    C<routing>
+    C<routing>,
+    C<version>,
+    C<version_type>
 
 See the L<exists docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/docs-get.html>
 for more information.
@@ -506,13 +543,15 @@ The C<delete()> method will delete the document with the specified
 C<index>, C<type> and C<id>, or will throw a C<Missing> error.
 
 Query string parameters:
-    C<consistency>,
+    C<error_trace>,
+    C<human>,
     C<parent>,
     C<refresh>,
     C<routing>,
     C<timeout>,
     C<version>,
-    C<version_type>
+    C<version_type>,
+    C<wait_for_active_shards>
 
 See the L<delete docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/docs-delete.html>
 for more information.
@@ -553,10 +592,6 @@ C<index>, C<type> and C<id> if it exists. Updates can be performed either by:
         }
     );
 
-Make sure you enable
-L<dynamic scripting|https://www.elastic.co/guide/en/elasticsearch/reference/current/modules-scripting.html#enable-dynamic-scripting>
-and know its implications.
-
 =item * with an indexed script:
 
     $response = $e->update(
@@ -564,6 +599,7 @@ and know its implications.
         body => {
             script => {
                 id     => $id,
+                lang   => 'painless',
                 params => { incr => 5 }
             }
         }
@@ -579,7 +615,7 @@ for more information.
         body => {
             script => {
                 file   => 'counter',
-                lang   => 'groovy',
+                lang   => 'painless',
                 params => { incr => 5 }
             }
         }
@@ -591,22 +627,23 @@ for more information.
 =back
 
 Query string parameters:
-    C<consistency>,
+    C<_source>,
+    C<_source_exclude>,
+    C<_source_include>,
+    C<error_trace>,
     C<fields>,
+    C<human>,
     C<lang>,
     C<parent>,
-    C<realtime>,
     C<refresh>,
     C<retry_on_conflict>,
     C<routing>,
-    C<script>,
-    C<script_id>,
-    C<scripted_upsert>,
     C<timeout>,
     C<timestamp>,
     C<ttl>,
     C<version>,
-    C<version_type>
+    C<version_type>,
+    C<wait_for_active_shards>
 
 See the L<update docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/docs-update.html>
 for more information.
@@ -626,9 +663,10 @@ offsets and payloads for the specified document, assuming that termvectors
 have been enabled.
 
 Query string parameters:
-    C<dfs>,
+    C<error_trace>,
     C<field_statistics>,
     C<fields>,
+    C<human>,
     C<offsets>,
     C<parent>,
     C<payloads>,
@@ -658,7 +696,7 @@ that need to be made, bulk requests greatly improve performance.
         body    => [ actions ]          # required
     );
 
-See L<Search::Elasticsearch::Client::2_0::Bulk> and L</bulk_helper()> for a helper module that makes
+See L<Search::Elasticsearch::Client::5_0::Bulk> and L</bulk_helper()> for a helper module that makes
 bulk indexing simpler to use.
 
 The C<bulk()> method can perform multiple L</index()>, L</create()>,
@@ -720,11 +758,17 @@ Each action is performed separately. One failed action will not
 cause the others to fail as well.
 
 Query string parameters:
-    C<consistency>,
+    C<_source>,
+    C<_source_exclude>,
+    C<_source_include>,
+    C<error_trace>,
     C<fields>,
+    C<human>,
+    C<pipeline>,
     C<refresh>,
     C<routing>,
-    C<timeout>
+    C<timeout>,
+    C<wait_for_active_shards>
 
 See the L<bulk docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/docs-bulk.html>
 for more information.
@@ -734,7 +778,7 @@ for more information.
     $bulk_helper = $e->bulk_helper( @args );
 
 Returns a new instance of the class specified in the L</bulk_helper_class>,
-which defaults to L<Search::Elasticsearch::Client::2_0::Bulk>.
+which defaults to L<Search::Elasticsearch::Client::5_0::Bulk>.
 
 =head2 C<mget()>
 
@@ -777,10 +821,13 @@ Query string parameters:
     C<_source>,
     C<_source_exclude>,
     C<_source_include>,
-    C<fields>,
+    C<error_trace>,
+    C<human>,
     C<preference>,
     C<realtime>,
-    C<refresh>
+    C<refresh>,
+    C<routing>,
+    C<stored_fields>
 
 See the L<mget docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/docs-multi-get.html>
 for more information.
@@ -807,8 +854,10 @@ Runs multiple L</termvector()> requests in a single request, eg:
     );
 
 Query string parameters:
+    C<error_trace>,
     C<field_statistics>,
     C<fields>,
+    C<human>,
     C<ids>,
     C<offsets>,
     C<parent>,
@@ -873,16 +922,20 @@ Query string parameters:
     C<allow_no_indices>,
     C<analyze_wildcard>,
     C<analyzer>,
+    C<batched_reduce_size>,
     C<default_operator>,
     C<df>,
+    C<docvalue_fields>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<explain>,
     C<fielddata_fields>,
-    C<fields>,
     C<from>,
+    C<human>,
     C<ignore_unavailable>,
     C<lenient>,
-    C<lowercase_expanded_terms>,
+    C<max_concurrent_shard_requests>,
+    C<pre_filter_shard_size>,
     C<preference>,
     C<q>,
     C<request_cache>,
@@ -892,6 +945,7 @@ Query string parameters:
     C<size>,
     C<sort>,
     C<stats>,
+    C<stored_fields>,
     C<suggest_field>,
     C<suggest_mode>,
     C<suggest_size>,
@@ -899,6 +953,7 @@ Query string parameters:
     C<terminate_after>,
     C<timeout>,
     C<track_scores>,
+    C<typed_keys>,
     C<version>
 
 See the L<search reference|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-request-body.html>
@@ -906,37 +961,6 @@ for more information.
 
 Also see L<Search::Elasticsearch::Transport/send_get_body_as>.
 
-=head2 C<search_exists()>
-
-The C<search_exists()> method is a quick version of search which can be
-used to find out whether there are matching search results or not.
-It doesn't return any results itself.
-
-    $results = $e->search_exists(
-        index   => 'index' | \@indices,     # optional
-        type    => 'type'  | \@types,       # optional
-
-        body    => { search params }        # optional
-    );
-
-Query string parameters:
-    C<allow_no_indices>,
-    C<analyze_wildcard>,
-    C<analyzer>,
-    C<default_operator>,
-    C<df>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>,
-    C<lenient>,
-    C<lowercase_expanded_terms>
-    C<min_score>,
-    C<preference>,
-    C<q>,
-    C<routing>
-
-See the L<search exists reference|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-exists.html>
-for more information.
-
 =head2 C<count()>
 
     $results = $e->count(
@@ -963,14 +987,17 @@ Query string parameters:
     C<analyzer>,
     C<default_operator>,
     C<df>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<lenient>,
     C<lowercase_expanded_terms>
     C<min_score>,
     C<preference>,
     C<q>,
-    C<routing>
+    C<routing>,
+    C<terminate_after>
 
 See the L<count docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-count.html>
 for more information.
@@ -1010,11 +1037,16 @@ for more information.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<explain>,
+    C<human>,
     C<ignore_unavailable>,
     C<preference>,
+    C<profile>,
     C<scroll>,
-    C<search_type>
+    C<search_type>,
+    C<typed_keys>
 
 =head2 C<render_search_template()>
 
@@ -1050,7 +1082,9 @@ for more information.
 
     $results = $e->scroll(
         scroll      => '1m',
-        scroll_id   => $id
+        body => {
+            scroll_id   => $id
+        }
     );
 
 When a L</search()> has been performed with the
@@ -1058,14 +1092,12 @@ C<scroll> parameter, the C<scroll()>
 method allows you to keep pulling more results until the results
 are exhausted.
 
-B<NOTE:> you will almost always want to set the
-C<search_type> to C<scan> in your
-original C<search()> request.
-
-See L</scroll_helper()> and L<Search::Elasticsearch::Client::2_0::Scroll> for a helper utility
+See L</scroll_helper()> and L<Search::Elasticsearch::Client::5_0::Scroll> for a helper utility
 which makes managing scroll requests much easier.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<scroll>,
     C<scroll_id>
 
@@ -1076,13 +1108,9 @@ for more information.
 =head2 C<clear_scroll()>
 
     $response = $e->clear_scroll(
-        scroll_id => $id | \@ids    # required
-    );
-
-Or
-
-    $response = $e->clear_scroll(
-        body => $id
+        body => {
+            scroll_id => $id | \@ids    # required
+        }
     );
 
 The C<clear_scroll()> method can clear unfinished scroll requests, freeing
@@ -1093,7 +1121,7 @@ up resources on the server.
     $scroll_helper = $e->scroll_helper( @args );
 
 Returns a new instance of the class specified in the L</scroll_helper_class>,
-which defaults to L<Search::Elasticsearch::Client::2_0::Scroll>.
+which defaults to L<Search::Elasticsearch::Client::5_0::Scroll>.
 
 =head2 C<msearch()>
 
@@ -1125,11 +1153,55 @@ request).  For instance:
     );
 
 Query string parameters:
-    C<search_type>
+    C<error_trace>,
+    C<human>,
+    C<max_concurrent_searches>,
+    C<pre_filter_shard_size>,
+    C<search_type>,
+    C<typed_keys>
 
 See the L<msearch docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-multi-search.html>
 for more information.
 
+=head2 C<msearch_template()>
+
+    $results = $e->msearch_template(
+        index   => 'default_index' | \@indices,     # optional
+        type    => 'default_type'  | \@types,       # optional
+
+        body    => [ search_templates ]             # required
+    );
+
+The C<msearch_template()> method allows you to perform multiple searches in a single
+request using search templates.  Similar to the L</bulk()> request, each search
+request in the C<body> consists of two hashes: the metadata hash then the search request
+hash (the same data that you'd specify in the C<body> of a L</search()>
+request).  For instance:
+
+    $results = $e->msearch(
+        index   => 'default_index',
+        type    => ['default_type_1', 'default_type_2'],
+        body => [
+            # uses defaults
+            {},
+            { inline => { query => { match => { user => "{{user}}" }}} params => { user => 'joe' }},
+
+            # uses a custom index
+            { index => 'not_the_default_index' },
+            { inline => { query => { match => { user => "{{user}}" }}} params => { user => 'joe' }},
+        ]
+    );
+
+Query string parameters:
+    C<error_trace>,
+    C<human>,
+    C<max_concurrent_searches>,
+    C<search_type>,
+    C<typed_keys>
+
+See the L<msearch-template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/multi-search-template.html>
+for more information.
+
 =head2 C<explain()>
 
     $response = $e->explain(
@@ -1163,17 +1235,38 @@ Query string parameters:
     C<analyzer>,
     C<default_operator>,
     C<df>,
-    C<fields>,
+    C<error_trace>,
+    C<human>,
     C<lenient>,
-    C<lowercase_expanded_terms>,
     C<parent>,
     C<preference>,
     C<q>,
-    C<routing>
+    C<routing>,
+    C<stored_fields>
 
 See the L<explain docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-explain.html>
 for more information.
 
+=head2 C<field_caps()>
+
+    $response = $e->field_caps(
+        index   => 'index'   | \@indices,   # optional
+        body    => { filters }              # optional
+    );
+
+The C<field-caps> API returns field types and abilities, merged across indices.
+
+Query string parameters:
+    C<allow_no_indices>,
+    C<error_trace>,
+    C<expand_wildcards>,
+    C<fields>,
+    C<human>,
+    C<ignore_unavailable>
+
+See the L<field-caps docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-field-caps.html>
+for more information.
+
 =head2 C<field_stats()>
 
     $response = $e->field_stats(
@@ -1188,8 +1281,10 @@ The C<field-stats> API returns statistical properties of a field
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<fields>,
+    C<human>,
     C<ignore_unavailable>,
     C<level>
 
@@ -1208,7 +1303,9 @@ which nodes will execute a search request.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<local>,
     C<preference>,
@@ -1224,26 +1321,48 @@ for more information.
     $response = $e->delete_by_query(
         index   => 'index' | \@indices,     # optional
         type    => 'type'  | \@types,       # optional,
-        body    => { delete-by-query }      # optional
+        body    => { delete-by-query }      # required
     );
 
-The C<delete_by_query()> method (available with the
-L<delete-by-query plugin|https://www.elastic.co/guide/en/elasticsearch/plugins/current/plugins-delete-by-query.html>)
-deletes all documents which match the specified query.
+The C<delete_by_query()> method deletes all documents which match the specified query.
 
 Query string parameters:
+    C<_source>,
+    C<_source_exclude>,
+    C<_source_include>,
     C<allow_no_indices>,
+    C<analyze_wildcard>,
     C<analyzer>,
+    C<conflicts>,
     C<default_operator>,
     C<df>,
+    C<error_trace>,
     C<expand_wildcards>,
-    C<filter_path>,
+    C<from>,
+    C<human>,
     C<ignore_unavailable>,
+    C<lenient>,
+    C<preference>,
     C<q>,
+    C<refresh>,
+    C<request_cache>,
+    C<requests_per_second>,
     C<routing>,
-    C<timeout>
+    C<scroll>,
+    C<scroll_size>,
+    C<search_timeout>,
+    C<search_type>,
+    C<size>,
+    C<slices>,
+    C<sort>,
+    C<stats>,
+    C<terminate_after>,
+    C<version>,
+    C<timeout>,
+    C<wait_for_active_shards>,
+    C<wait_for_completion>
 
-See the L<delete-by-query docs|https://www.elastic.co/guide/en/elasticsearch/plugins/current/plugins-delete-by-query.html>
+See the L<delete-by-query docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-delete-by-query.html>
 for more information.
 
 =head2 C<reindex()>
@@ -1256,10 +1375,13 @@ The C<reindex()> API is used to index documents from one index or multiple indic
 to a new index.
 
 Query string parameters:
-    C<consistency>,
+    C<error_trace>,
+    C<human>,
     C<refresh>,
     C<requests_per_second>,
+    C<slices>,
     C<timeout>,
+    C<wait_for_active_shards>,
     C<wait_for_completion>
 
 See the L<reindex docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-reindex.html>
@@ -1284,17 +1406,15 @@ Query string parameters:
     C<analyze_wildcard>,
     C<analyzer>,
     C<conflicts>,
-    C<consistency>,
     C<default_operator>,
     C<df>,
+    C<error_trace>,
     C<expand_wildcards>,
-    C<explain>,
-    C<fielddata_fields>,
-    C<fields>,
     C<from>,
+    C<human>,
     C<ignore_unavailable>,
     C<lenient>,
-    C<lowercase_expanded_terms>,
+    C<pipeline>,
     C<preference>,
     C<q>,
     C<refresh>,
@@ -1306,17 +1426,14 @@ Query string parameters:
     C<search_timeout>,
     C<search_type>,
     C<size>,
+    C<slices>,
     C<sort>,
     C<stats>,
-    C<suggest_field>,
-    C<suggest_mode>,
-    C<suggest_size>,
-    C<suggest_text>,
     C<terminate_after>,
     C<timeout>,
-    C<track_scores>,
     C<version>,
     C<version_type>,
+    C<wait_for_active_shards>,
     C<wait_for_completion>
 
 See the L<update_by_query docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-update-by-query.html>
@@ -1333,6 +1450,8 @@ The C<reindex_rethrottle()> API is used to dynamically update the throtting
 of an existing reindex request, identified by C<task_id>.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<requests_per_second>
 
 See the L<reindex docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-reindex.html>
@@ -1369,7 +1488,9 @@ C<_source> field of the document under the C<doc> key:
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<percolate_format>,
     C<percolate_index>,
@@ -1409,7 +1530,9 @@ of the queries themselves.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<percolate_index>,
     C<percolate_type>,
@@ -1456,7 +1579,9 @@ in a single request.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>
 
 See the L<mpercolate docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-percolate.html>
@@ -1489,15 +1614,17 @@ suggestion requests, which can also be run as part of a L</search()> request.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<preference>,
     C<routing>
 
 =head1 INDEXED SCRIPT METHODS
 
-If dynamic scripting is enabled, Elasticsearch allows you to store scripts in an internal index known as
-C<.scripts> and reference them by id. The methods to manage indexed scripts are as follows:
+Elasticsearch allows you to store scripts in the cluster state
+and reference them by id. The methods to manage indexed scripts are as follows:
 
 =head2 C<put_script()>
 
@@ -1507,10 +1634,10 @@ C<.scripts> and reference them by id. The methods to manage indexed scripts are
         body => { script }  # required
     );
 
-The C<put_script()> method is used to store a script in the C<.scripts> index. For instance:
+The C<put_script()> method is used to store a script in the cluster state. For instance:
 
     $result  = $e->put_scripts(
-        lang => 'groovy',
+        lang => 'painless',
         id   => 'hello_world',
         body => {
           script => q(return "hello world");
@@ -1518,9 +1645,10 @@ The C<put_script()> method is used to store a script in the C<.scripts> index. F
     );
 
 Query string parameters:
-    C<op_type>,
-    C<version>,
-    C<version_type>
+    C<error_trace>,
+    C<human>,
+    C<master_timeout>,
+    C<timeout>
 
 See the L<indexed scripts docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/modules-scripting.html#_indexed_scripts> for more.
 
@@ -1531,11 +1659,11 @@ See the L<indexed scripts docs|http://www.elastic.co/guide/en/elasticsearch/refe
         id   => 'id',       # required
     );
 
-Retrieve the indexed script from the C<.scripts> index.
+Retrieve the indexed script from the cluster state.
 
 Query string parameters:
-    C<version>,
-    C<version_type>
+    C<error_trace>,
+    C<human>
 
 See the L<indexed scripts docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/modules-scripting.html#_indexed_scripts> for more.
 
@@ -1546,18 +1674,20 @@ See the L<indexed scripts docs|http://www.elastic.co/guide/en/elasticsearch/refe
         id   => 'id',       # required
     );
 
-Delete the indexed script from the C<.scripts> index.
+Delete the indexed script from the cluster state.
 
 Query string parameters:
-    C<version>,
-    C<version_type>
+    C<error_trace>,
+    C<human>,
+    C<master_timeout>,
+    C<timeout>
 
 See the L<indexed scripts docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/modules-scripting.html#_indexed_scripts> for more.
 
 =head1 INDEXED SEARCH TEMPLATE METHODS
 
 Mustache templates can be used to create search requests.  These templates can
-be stored in the C<.scripts> index and retrieved by ID. The methods to
+be stored in the cluster state and retrieved by ID. The methods to
 manage indexed scripts are as follows:
 
 =head2 C<put_template()>
@@ -1567,7 +1697,7 @@ manage indexed scripts are as follows:
         body => { template } || "template"  # required
     );
 
-The C<put_template()> method is used to store a template in the C<.scripts> index.
+The C<put_template()> method is used to store a template in the cluster state.
 For instance:
 
     $result  = $e->put_template(
@@ -1583,7 +1713,9 @@ For instance:
       }
     );
 
-Query string parameters: None
+Query string parameters:
+    C<error_trace>,
+    C<human>
 
 See the L<indexed search template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-template.html#_pre_registered_template> for more.
 
@@ -1593,11 +1725,11 @@ See the L<indexed search template docs|http://www.elastic.co/guide/en/elasticsea
         id   => 'id',       # required
     );
 
-Retrieve the indexed template from the C<.scripts> index.
+Retrieve the indexed template from the cluster state.
 
 Query string parameters:
-    C<version>,
-    C<version_type>
+    C<error_trace>,
+    C<human>
 
 See the L<indexed search template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-template.html#_pre_registered_template> for more.
 
@@ -1607,19 +1739,21 @@ See the L<indexed search template docs|http://www.elastic.co/guide/en/elasticsea
         id   => 'id',       # required
     );
 
-Delete the indexed template from the C<.scripts> index.
+Delete the indexed template from the cluster state.
 
-Query string parameters: None
+Query string parameters:
+    C<error_trace>,
+    C<human>
 
 See the L<indexed search template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-template.html#_pre_registered_template> for more.
 
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2017 by Elasticsearch BV.
 
 This is free software, licensed under:
 
@@ -1629,5 +1763,5 @@ This is free software, licensed under:
 
 __END__
 
-# ABSTRACT: Thin client with full support for Elasticsearch 2.x APIs
+# ABSTRACT: Thin client with full support for Elasticsearch 5.x APIs
 
