@@ -1,13 +1,7 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::2_0::Direct::Cluster;
-$Search::Elasticsearch::Client::2_0::Direct::Cluster::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::2_0::Direct::Cluster::VERSION = '7.301';
+package Search::Elasticsearch::Client::5_0::Direct::Cluster;
+$Search::Elasticsearch::Client::5_0::Direct::Cluster::VERSION = '6.00';
 use Moo;
-with 'Search::Elasticsearch::Client::2_0::Role::API';
+with 'Search::Elasticsearch::Client::5_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('cluster');
 
@@ -19,11 +13,11 @@ __PACKAGE__->_install_api('cluster');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::2_0::Direct::Cluster - A client for running cluster-level requests
+Search::Elasticsearch::Client::5_0::Direct::Cluster - A client for running cluster-level requests
 
 =head1 VERSION
 
-version 7.30_1
+version 6.00
 
 =head1 DESCRIPTION
 
@@ -46,13 +40,16 @@ health, returning C<red>, C<yellow> or C<green> to indicate the state
 of the cluster, indices or shards.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<level>,
     C<local>,
     C<master_timeout>,
     C<timeout>,
     C<wait_for_active_shards>,
+    C<wait_for_events>,
+    C<wait_for_no_relocating_shards>,
     C<wait_for_nodes>,
-    C<wait_for_relocating_shards>,
     C<wait_for_status>
 
 See the L<cluster health docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-health.html>
@@ -67,6 +64,7 @@ for more information.
 Returns high-level cluster stats, optionally limited to the listed nodes.
 
 Query string parameters:
+    C<error_trace>,
     C<flat_settings>,
     C<human>,
     C<timeout>
@@ -82,7 +80,10 @@ The C<get_settings()> method is used to retrieve cluster-wide settings that
 have been set with the L</put_settings()> method.
 
 Query string parameters:
+    C<error_trace>,
     C<flat_settings>,
+    C<human>,
+    C<include_defaults>,
     C<master_timeout>,
     C<timeout>
 
@@ -106,7 +107,9 @@ For instance:
     );
 
 Query string parameters:
-    C<flat_settings>
+    C<error_trace>,
+    C<flat_settings>,
+    C<human>
 
 See the L<cluster settings docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-update-settings.html>
  for more information.
@@ -133,8 +136,10 @@ parameter.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<flat_settings>,
+    C<human>,
     C<ignore_unavailable>,
     C<local>,
     C<master_timeout>
@@ -142,6 +147,23 @@ Query string parameters:
 See the L<cluster state docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-state.html>
 for more information.
 
+=head2 C<allocation_explain()>
+
+    $response = $e->cluster->allocation_explain(
+        body => { ... shard selectors ...}  # optional
+    );
+
+Returns information about why a shard is allocated or unallocated or why.
+
+Query string parameters:
+    C<error_trace>,
+    C<human>,
+    C<include_disk_info>,
+    C<include_yes_decisions>
+
+See the L<cluster allocation explain docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-allocation-explain.html>
+for more information.
+
 =head2 C<pending_tasks()>
 
     $response = $e->cluster->pending_tasks();
@@ -149,6 +171,8 @@ for more information.
 Returns a list of cluster-level tasks still pending on the master node.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<local>,
     C<master_timeout>
 
@@ -185,21 +209,37 @@ which changes should be made. For instance:
 
 Query string parameters:
     C<dry_run>,
+    C<error_trace>,
     C<explain>,
+    C<human>,
     C<master_timeout>,
     C<metric>,
+    C<retry_failed>,
     C<timeout>
 
 See the L<reroute docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-reroute.html>
 for more information.
 
+=head2 C<remote_info()>
+
+    $response = $e->cluster->remote_info();
+
+The C<remote_info()> API retrieves all of the configured remote cluster information.
+
+Query string parameters:
+    C<error_trace>,
+    C<human>
+
+See the L<remote_info docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-remote-info.html>
+for more information.
+
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2017 by Elasticsearch BV.
 
 This is free software, licensed under:
 
