@@ -1,13 +1,7 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::2_0::Direct::Indices;
-$Search::Elasticsearch::Client::2_0::Direct::Indices::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::2_0::Direct::Indices::VERSION = '7.301';
+package Search::Elasticsearch::Client::5_0::Direct::Indices;
+$Search::Elasticsearch::Client::5_0::Direct::Indices::VERSION = '6.00';
 use Moo;
-with 'Search::Elasticsearch::Client::2_0::Role::API';
+with 'Search::Elasticsearch::Client::5_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('indices');
 
@@ -19,17 +13,17 @@ __PACKAGE__->_install_api('indices');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::2_0::Direct::Indices - A client for running index-level requests
+Search::Elasticsearch::Client::5_0::Direct::Indices - A client for running index-level requests
 
 =head1 VERSION
 
-version 7.30_1
+version 6.00
 
 =head1 DESCRIPTION
 
 This module provides methods to make index-level requests, such as
 creating and deleting indices, managing type mappings, index settings,
-warmers, index templates and aliases.
+index templates and aliases.
 
 It does L<Search::Elasticsearch::Role::Client::Direct>.
 
@@ -43,17 +37,20 @@ It does L<Search::Elasticsearch::Role::Client::Direct>.
         body  => {                      # optional
             index settings
             mappings
-            warmers
+            aliases
         }
     );
 
 The C<create()> method is used to create an index. Optionally, index
-settings, type mappings and index warmers can be added at the same time.
+settings, type mappings, and aliases can be added at the same time.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<timeout>,
-    C<update_all_types>
+    C<update_all_types>,
+    C<wait_for_active_shards>
 
 See the L<create index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-create-index.html>
 for more information.
@@ -65,17 +62,20 @@ for more information.
         feature => 'feature' | \@features   # optional
     );
 
-Returns the aliases, settings, mappings, and warmers for the specified indices.
+Returns the aliases, settings, and mappingsfor the specified indices.
 The C<feature> parameter can be set to none or more of: C<_settings>, C<_mappings>,
-C<_warmers> and C<_aliases>.
+and C<_aliases>.
 
 See the L<get index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-get-index.html>.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<flat_settings>,
     C<human>,
     C<ignore_unavailable>,
+    C<include_defaults>,
     C<local>
 
 =head2 C<exists()>
@@ -89,8 +89,12 @@ whether the specified index or indices exist.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<flat_settings>,
+    C<human>,
     C<ignore_unavailable>,
+    C<include_defaults>,
     C<local>
 
 See the L<index exists docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-indices-exists.html>
@@ -106,7 +110,9 @@ The C<delete()> method deletes the specified indices.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<master_timeout>,
     C<timeout>
@@ -125,7 +131,9 @@ but allowing them to be reopened later.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>
     C<master_timeout>,
     C<timeout>
@@ -143,7 +151,9 @@ The C<open()> method opens closed indices.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>
     C<master_timeout>,
     C<timeout>
@@ -151,6 +161,49 @@ Query string parameters:
 See the L<open index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-open-close.html>
 for more information.
 
+=head2 C<rollover()>
+
+    $response = $e->indices->rollover(
+        alias     => $alias,                    # required
+        new_index => $index,                    # optional
+        body      => { rollover conditions }    # optional
+    );
+
+Rollover an index pointed to by C<alias> if it meets rollover conditions
+(eg max age, max docs) to a new index name.
+
+Query string parameters:
+    C<dry_run>,
+    C<error_trace>,
+    C<human>,
+    C<master_timeout>,
+    C<timeout>,
+    C<wait_for_active_shards>
+
+See the L<rollover index docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-rollover-index.html>
+for more information.
+
+=head2 C<shrink()>
+
+    $response = $e->shrink(
+        index  => $index,                           # required
+        target => $target,                          # required
+        body   => { mappings, settings aliases }    # optional
+    );
+
+The shrink API shrinks the shards of an index down to a single shard (or to a factor
+of the original shards).
+
+Query string parameters:
+    C<error_trace>,
+    C<human>,
+    C<master_timeout>,
+    C<timeout>,
+    C<wait_for_active_shards>
+
+See the L<shrink index docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-shrink-index.html>
+for more information.
+
 =head2 C<clear_cache()>
 
     $response = $e->indices->clear_cache(
@@ -162,9 +215,11 @@ or id cache for the specified indices.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<fielddata>,
     C<fields>,
+    C<human>,
     C<ignore_unavailable>,
     C<query>,
     C<recycler>,
@@ -185,8 +240,9 @@ happens automatically once every second by default.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
-    C<force>,
+    C<human>,
     C<ignore_unavailable>
 
 See the L<refresh index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-refresh.html>
@@ -204,8 +260,10 @@ This process normally happens automatically.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<force>,
+    C<human>,
     C<ignore_unavailable>,
     C<wait_if_ongoing>
 
@@ -234,7 +292,9 @@ for more information.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>
 
 =head2 C<forcemerge()>
@@ -249,8 +309,10 @@ with care, and only on indices that are no longer being updated.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<flush>,
+    C<human>,
     C<ignore_unavailable>,
     C<max_num_segments>,
     C<only_expunge_deletes>,
@@ -259,30 +321,6 @@ Query string parameters:
 See the L<forcemerge docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-forcemerge.html>
 for more information.
 
-=head2 C<optimize()>
-
-The C<optimize()> method is deprecated in 2.x and will be replaced by L<forcemerge()>;
-
-    $response = $e->indices->optimize(
-        index => 'index' | \@indices    # optional
-    );
-
-The C<optimize()> method rewrites all the data in an index into at most
-C<max_num_segments>.  This is a very heavy operation and should only be run
-with care, and only on indices that are no longer being updated.
-
-Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<flush>,
-    C<ignore_unavailable>,
-    C<max_num_segments>,
-    C<only_expunge_deletes>,
-    C<wait_for_merge>
-
-See the L<optimize index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-optimize.html>
-for more information.
-
 =head2 C<get_upgrade()>
 
     $response = $e->indices->get_upgrade(
@@ -294,6 +332,7 @@ upgraded, which can be done with the C<upgrade()> method.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<human>,
     C<ignore_unavailable>
@@ -311,7 +350,9 @@ The C<upgrade()> method upgrades all segments in the specified indices to the la
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<only_ancient_segments>,
     C<wait_for_completion>
@@ -351,7 +392,9 @@ For instance:
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<master_timeout>,
     C<timeout>,
@@ -372,7 +415,9 @@ all types in one, more or all indices.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<local>
 
@@ -394,7 +439,9 @@ all fields in one, more or all types and indices.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<include_defaults>,
     C<local>
@@ -414,7 +461,9 @@ in all specified indices, and returns C<1> or the empty string.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<local>
 
@@ -442,29 +491,14 @@ index aliases atomically. For instance:
     );
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<timeout>
 
 See the L<update_aliases docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html>
 for more information.
 
-=head2 C<get_aliases()>
-
-    $result = $e->indices->get_aliases(
-        index   => 'index' | \@indices,     # optional
-        alias   => 'alias' | \@aliases      # optional
-    );
-
-The C<get_aliases()> method returns a list of aliases per index for all
-the specified indices.
-
-Query string parameters:
-    C<local>,
-    C<timeout>
-
-See the L<get_aliases docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html>
-for more information.
-
 =head2 C<put_alias()>
 
     $response = $e->indices->put_alias(
@@ -485,6 +519,8 @@ The C<put_alias()> method creates an index alias. For instance:
     );
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<timeout>
 
@@ -503,7 +539,9 @@ aliases in the specified indices.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<local>
 
@@ -522,7 +560,9 @@ whether the specified aliases exist in the specified indices.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<local>
 
@@ -540,6 +580,8 @@ The C<delete_alias()> method deletes one or more aliases from one or more
 indices.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<timeout>
 
@@ -567,10 +609,13 @@ indices or all indices. For instance:
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<flat_settings>,
+    C<human>,
     C<ignore_unavailable>,
-    C<master_timeout>
+    C<master_timeout>,
+    C<preserve_existing>
 
 See the L<put_settings docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-update-settings.html>
 for more information.
@@ -587,10 +632,12 @@ indices or all indices.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<flat_settings>,
     C<human>,
     C<ignore_unavailable>,
+    C<include_defaults>,
     C<local>
 
 See the L<get_settings docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-get-settings.html>
@@ -609,7 +656,9 @@ The C<put_template()> method is used to create or update index templates.
 
 Query string parameters:
     C<create>,
+    C<error_trace>,
     C<flat_settings>,
+    C<human>,
     C<master_timeout>,
     C<op_type>,
     C<order>,
@@ -629,7 +678,9 @@ for more information.
 The C<get_template()> method is used to retrieve a named template.
 
 Query string parameters:
+    C<error_trace>,
     C<flat_settings>,
+    C<human>,
     C<local>,
     C<master_timeout>
 
@@ -639,12 +690,15 @@ for more information.
 =head2 C<exists_template()>
 
     $result = $e->indices->exists_template(
-        name  => 'template'                 # required
+        name  => 'template' | \@templates   # required
     );
 
 The C<exists_template()> method is used to check whether the named template exists.
 
 Query string parameters:
+    C<error_trace>,
+    C<flat_settings>,
+    C<human>,
     C<local>,
     C<master_timeout>
 
@@ -660,6 +714,8 @@ for more information.
 The C<delete_template()> method is used to delete a named template.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<timeout>,
     C<version>,
@@ -668,74 +724,6 @@ Query string parameters:
 See the L<delete_template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-templates.html>
 for more information.
 
-=head1 WARMER METHODS
-
-=head2 C<put_warmer()>
-
-    $response = $e->indices->put_warmer(
-        index   => 'index' | \@indices,     # optional
-        type    => 'type'  | \@types,       # optional
-        name    => 'warmer',                # required
-
-        body    => { warmer defn }          # required
-    );
-
-The C<put_warmer()> method is used to create or update named warmers which
-are used to I<warm up> new segments in the index before they are exposed
-to user searches.  For instance:
-
-    $response = $e->indices->put_warmer(
-        index   => 'my_index',
-        name    => 'date_field_warmer',
-        body    => {
-            sort => 'date'
-        }
-    );
-
-Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>,
-    C<master_timeout>,
-    C<request_cache>
-
-See the L<put_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-warmers.html>
-for more information.
-
-=head2 C<get_warmer()>
-
-    $response = $e->indices->get_warmer(
-        index   => 'index'  | \@indices,    # optional
-        type    => 'type'   | \@types,      # optional
-        name    => 'warmer' | \@warmers,    # optional
-    );
-
-The C<get_warmer()> method is used to retrieve warmers by name.
-
-Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>,
-    C<local>
-
-See the L<get_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-warmers.html>
-for more information.
-
-=head2 C<delete_warmer()>
-
-    $response = $e->indices->get_warmer(
-        index   => 'index'  | \@indices,    # required
-        name    => 'warmer' | \@warmers,    # required
-    );
-
-The C<delete_warmer()> method is used to delete warmers by name.
-
-Query string parameters:
-    C<master_timeout>
-
-See the L<delete_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-warmers.html>
-for more information.
-
 =head1 STATS METHODS
 
 =head2 C<stats()>
@@ -766,15 +754,16 @@ Allowed metrics are:
     C<request_cache>,
     C<search>,
     C<segments>,
-    C<store>,
-    C<warmer>
+    C<store>
 
 Query string parameters:
     C<completion_fields>,
+    C<error_trace>,
     C<fielddata_fields>,
     C<fields>,
     C<groups>,
     C<human>,
+    C<include_segment_file_sizes>,
     C<level>,
     C<types>
 
@@ -792,6 +781,7 @@ Provides insight into on-going shard recoveries.
 Query string parameters:
     C<active_only>,
     C<detailed>,
+    C<error_trace>,
     C<human>
 
 See the L<recovery docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-recovery.html>
@@ -808,6 +798,7 @@ that an index contains.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<human>,
     C<ignore_unavailable>,
@@ -827,6 +818,7 @@ copies of which shards, whether the shards are allocated or not.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<human>,
     C<ignore_unavailable>,
@@ -853,6 +845,7 @@ Query string parameters:
     C<analyzer>,
     C<attributes>,
     C<char_filter>,
+    C<error_trace>,
     C<explain>,
     C<field>,
     C<filter>,
@@ -878,16 +871,17 @@ whether the query is valid or not.  Most useful when C<explain> is set
 to C<true>, in which case it includes an execution plan in the output.
 
 Query string parameters:
+    C<all_shards>,
     C<allow_no_indices>,
     C<analyze_wildcard>,
     C<analyzer>,
     C<default_operator>,
     C<df>,
+    C<error_trace>,
     C<explain>,
     C<expand_wildcards>,
     C<ignore_unavailable>,
     C<lenient>,
-    C<lowercase_expanded_terms>
     C<q>,
     C<rewrite>
 
@@ -896,11 +890,11 @@ for more information.
 
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2017 by Elasticsearch BV.
 
 This is free software, licensed under:
 
