@@ -1,13 +1,7 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::2_0::Direct::Nodes;
-$Search::Elasticsearch::Client::2_0::Direct::Nodes::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::2_0::Direct::Nodes::VERSION = '7.301';
+package Search::Elasticsearch::Client::5_0::Direct::Nodes;
+$Search::Elasticsearch::Client::5_0::Direct::Nodes::VERSION = '6.00';
 use Moo;
-with 'Search::Elasticsearch::Client::2_0::Role::API';
+with 'Search::Elasticsearch::Client::5_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('nodes');
 
@@ -19,11 +13,11 @@ __PACKAGE__->_install_api('nodes');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::2_0::Direct::Nodes - A client for running node-level requests
+Search::Elasticsearch::Client::5_0::Direct::Nodes - A client for running node-level requests
 
 =head1 VERSION
 
-version 7.30_1
+version 6.00
 
 =head1 DESCRIPTION
 
@@ -58,6 +52,7 @@ Allowed metrics are:
     C<transport>
 
 Query string parameters:
+    C<error_trace>,
     C<flat_settings>,
     C<human>
 
@@ -85,6 +80,7 @@ Allowed metrics are:
     C<breaker>,
     C<fs>,
     C<http>,
+    C<include_segment_file_sizes>,
     C<indices>,
     C<jvm>,
     C<network>,
@@ -95,7 +91,7 @@ Allowed metrics are:
     C<transport>
 
 If the C<indices> metric (or C<_all>) is specified, then
-L<indices_stats|Search::Elasticsearch::Client::2_0::Direct::Indices/indices_stats()>
+L<indices_stats|Search::Elasticsearch::Client::5_0::Direct::Indices/indices_stats()>
 information is returned on a per-node basis. Which indices stats are
 returned can be controlled with the C<index_metric> parameter:
 
@@ -126,6 +122,7 @@ Allowed index metrics are:
 
 Query string parameters:
     C<completion_fields>,
+    C<error_trace>,
     C<fielddata_fields>,
     C<fields>,
     C<groups>,
@@ -146,6 +143,8 @@ The C<hot_threads()> method is a useful tool for diagnosing busy nodes. It
 takes a snapshot of which threads are consuming the most CPU.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<ignore_idle_threads>,
     C<interval>,
     C<snapshots>,
@@ -158,11 +157,11 @@ for more information.
 
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2017 by Elasticsearch BV.
 
 This is free software, licensed under:
 
