@@ -1,13 +1,7 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::2_0::Direct::Snapshot;
-$Search::Elasticsearch::Client::2_0::Direct::Snapshot::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::2_0::Direct::Snapshot::VERSION = '7.301';
+package Search::Elasticsearch::Client::5_0::Direct::Snapshot;
+$Search::Elasticsearch::Client::5_0::Direct::Snapshot::VERSION = '6.00';
 use Moo;
-with 'Search::Elasticsearch::Client::2_0::Role::API';
+with 'Search::Elasticsearch::Client::5_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('snapshot');
 
@@ -19,11 +13,11 @@ __PACKAGE__->_install_api('snapshot');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::2_0::Direct::Snapshot - A client for managing snapshot/restore
+Search::Elasticsearch::Client::5_0::Direct::Snapshot - A client for managing snapshot/restore
 
 =head1 VERSION
 
-version 7.30_1
+version 6.00
 
 =head1 DESCRIPTION
 
@@ -45,6 +39,8 @@ It does L<Search::Elasticsearch::Role::Client::Direct>.
 Create a repository for backups.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<timeout>,
     C<verify>
@@ -61,6 +57,8 @@ for more information.
 Retrieve existing repositories.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<local>,
     C<master_timeout>
 
@@ -76,6 +74,8 @@ for more information.
 Verify existing repository.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<timeout>
 
@@ -91,6 +91,8 @@ for more information.
 Delete repositories by name.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<timeout>
 
@@ -110,6 +112,8 @@ Create a snapshot of the whole cluster or individual indices in the named
 repository.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<wait_for_completion>
 
@@ -123,7 +127,11 @@ Query string parameters:
 Retrieve snapshots in the named repository.
 
 Query string parameters:
-    C<master_timeout>
+    C<error_trace>,
+    C<human>,
+    C<ignore_unavailable>,
+    C<master_timeout>,
+    C<verbose>
 
 See the L<"snapshot/restore docs"|http://www.elastic.co/guide/en/elasticsearch/reference/current/modules-snapshot.html>
 for more information.
@@ -138,6 +146,8 @@ for more information.
 Delete snapshot in the named repository.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>
 
 See the L<"snapshot/restore docs"|http://www.elastic.co/guide/en/elasticsearch/reference/current/modules-snapshot.html>
@@ -155,6 +165,8 @@ for more information.
 Restore a named snapshot.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<master_timeout>,
     C<wait_for_completion>
 
@@ -171,6 +183,9 @@ for more information.
 Returns status information about the specified snapshots.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
+    C<ignore_unavailable>,
     C<master_timeout>
 
 See the L<"snapshot/restore docs"|http://www.elastic.co/guide/en/elasticsearch/reference/current/modules-snapshot.html>
@@ -178,11 +193,11 @@ for more information.
 
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2017 by Elasticsearch BV.
 
 This is free software, licensed under:
 
