@@ -1,17 +1,10 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::2_0::Role::Scroll;
-$Search::Elasticsearch::Client::2_0::Role::Scroll::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::2_0::Role::Scroll::VERSION = '7.301';
+package Search::Elasticsearch::Client::5_0::Role::Scroll;
+$Search::Elasticsearch::Client::5_0::Role::Scroll::VERSION = '6.00';
 use Moo::Role;
 requires 'finish';
 use Search::Elasticsearch::Util qw(parse_params throw);
 use Devel::GlobalDestruction;
 use namespace::clean;
-
 has 'es' => ( is => 'ro', required => 1 );
 has 'scroll'        => ( is => 'ro' );
 has 'scroll_in_qs'  => ( is => 'ro' );
@@ -41,7 +34,7 @@ sub scroll_request {
         $args{scroll_id} = $self->_scroll_id;
     }
     else {
-        $args{body} = $self->_scroll_id;
+        $args{body} = { scroll_id => $self->_scroll_id };
     }
     $self->es->scroll(%args);
 }
@@ -56,7 +49,7 @@ sub DEMOLISH {
 
 1;
 
-# ABSTRACT: Provides common functionality to L<Search::Elasticsearch::Client::2_0::Scroll> and L<Search::Elasticsearch::Client::2_0::Async::Scroll>
+# ABSTRACT: Provides common functionality to L<Search::Elasticsearch::Client::5_0::Scroll> and L<Search::Elasticsearch::Client::5_0::Async::Scroll>
 
 __END__
 
@@ -66,19 +59,19 @@ __END__
 
 =head1 NAME
 
-Search::Elasticsearch::Client::2_0::Role::Scroll - Provides common functionality to L<Search::Elasticsearch::Client::2_0::Scroll> and L<Search::Elasticsearch::Client::2_0::Async::Scroll>
+Search::Elasticsearch::Client::5_0::Role::Scroll - Provides common functionality to L<Search::Elasticsearch::Client::5_0::Scroll> and L<Search::Elasticsearch::Client::5_0::Async::Scroll>
 
 =head1 VERSION
 
-version 7.30_1
+version 6.00
 
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2017 by Elasticsearch BV.
 
 This is free software, licensed under:
 
