@@ -1,11 +1,5 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::2_0::Scroll;
-$Search::Elasticsearch::Client::2_0::Scroll::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::2_0::Scroll::VERSION = '7.301';
+package Search::Elasticsearch::Client::5_0::Scroll;
+$Search::Elasticsearch::Client::5_0::Scroll::VERSION = '6.00';
 use Moo;
 use Search::Elasticsearch::Util qw(parse_params throw);
 use namespace::clean;
@@ -13,7 +7,7 @@ use namespace::clean;
 has '_buffer' => ( is => 'ro' );
 
 with 'Search::Elasticsearch::Role::Is_Sync',
-    'Search::Elasticsearch::Client::2_0::Role::Scroll';
+    'Search::Elasticsearch::Client::5_0::Role::Scroll';
 
 #===================================
 sub BUILDARGS {
@@ -115,7 +109,7 @@ sub finish {
     my %args
         = $self->scroll_in_qs
         ? ( scroll_id => $scroll_id )
-        : ( body => $scroll_id );
+        : ( body => { scroll_id => [$scroll_id] } );
     eval { $self->es->clear_scroll(%args) };
     return 1;
 }
@@ -128,11 +122,11 @@ sub finish {
 
 =head1 NAME
 
-Search::Elasticsearch::Client::2_0::Scroll - A helper module for scrolled searches
+Search::Elasticsearch::Client::5_0::Scroll - A helper module for scrolled searches
 
 =head1 VERSION
 
-version 7.30_1
+version 6.00
 
 =head1 SYNOPSIS
 
@@ -142,8 +136,11 @@ version 7.30_1
 
     my $scroll = $es->scroll_helper(
         index       => 'my_index',
-        search_type => 'scan',
-        size        => 500
+        body => {
+            query   => {...},
+            size    => 1000,
+            sort    => '_doc'
+        }
     );
 
     say "Total hits: ". $scroll->total;
@@ -159,20 +156,17 @@ until there are no more matching results, much like a cursor in an SQL
 database.
 
 Unlike paginating through results (with the C<from> parameter in
-L<search()|Search::Elasticsearch::Client::2_0::Direct/search()>),
+L<search()|Search::Elasticsearch::Client::5_0::Direct/search()>),
 scrolled searches take a snapshot of the current state of the index. Even
 if you keep adding new documents to the index or updating existing documents,
 a scrolled search will only see the index as it was when the search began.
 
 This module is a helper utility that wraps the functionality of the
-L<search()|Search::Elasticsearch::Client::2_0::Direct/search()> and
-L<scroll()|Search::Elasticsearch::Client::2_0::Direct/scroll()> methods to make
+L<search()|Search::Elasticsearch::Client::5_0::Direct/search()> and
+L<scroll()|Search::Elasticsearch::Client::5_0::Direct/scroll()> methods to make
 them easier to use.
 
-B<IMPORTANT>: Deep scrolling can be expensive.  See L</DEEP SCROLLING>
-for more.
-
-This class does L<Search::Elasticsearch::Client::2_0::Role::Scroll> and
+This class does L<Search::Elasticsearch::Client::5_0::Role::Scroll> and
 L<Search::Elasticsearch::Role::Is_Sync>.
 
 =head1 USE CASES
@@ -220,14 +214,14 @@ C<client_id>:
 
     my $scroll = $es->scroll_helper(
         index       => 'my_index',
-        search_type => 'scan',          # important!
-        size        => 500,
+        size        => 1000,
         body        => {
             query => {
                 match => {
                     client_id => 123
                 }
-            }
+            },
+            sort => '_doc'
         }
     );
 
@@ -237,42 +231,8 @@ C<client_id>:
 
 Very often the I<something> that you will want to do with these results
 involves bulk-indexing them into a new index. The easiest way to
-marry a scrolled search with bulk indexing is to use the
-L<Search::Elasticsearch::Client::2_0::Bulk/reindex()> method.
-
-=head1 DEEP SCROLLING
-
-Deep scrolling (and deep pagination) are very expensive in a distributed
-environment, and the reason they are expensive is that results need to
-be sorted in a global order.
-
-For example, if we have an index with 5 shards, and we request the first
-10 results, each shard has to return its top 10, and then the I<requesting
-node> (the node that is handling the search request) has to resort these
-50 results to return a global top 10. Now, if we request page 1,000
-(ie results 10,001 .. 10,010), then each shard has to return 10,010 results,
-and the requesting node has to sort through 50,050 results just to return
-10 of them!
-
-You can see how this can get very heavy very quickly. This is the reason that
-web search engines never return more than 1,000 results.
-
-=head2 Disable sorting for efficient scrolling
-
-The problem with deep scrolling is the sorting phase.  If we disable sorting,
-then we can happily scroll through millions of documents efficiently.  The
-way to do this is to set C<search_type> to C<scan>:
-
-    my $scroll = $es->scroll_helper(
-        search_type => 'scan',
-        size        => 500,
-    );
-
-Scanning disables sorting and will just return C<size> results from each
-shard until there are no more results to return. B<Note>: this means
-that, when querying an index with 5 shards, the scrolled search
-will pull C<size * 5> results at a time. If you have large documents or
-are memory constrained, you will need to take this into account.
+do this is to use the built-in L<Search::Elasticsearch::Client::5_0::Direct/reindex()>
+functionality provided by Elasticsearch.
 
 =head1 METHODS
 
@@ -287,13 +247,13 @@ are memory constrained, you will need to take this into account.
         %search_params
     );
 
-The L<Search::Elasticsearch::Client::2_0::Direct/scroll_helper()> method loads
-L<Search::Elasticsearch::Client::2_0::Scroll> class and calls L</new()>,
+The L<Search::Elasticsearch::Client::5_0::Direct/scroll_helper()> method loads
+L<Search::Elasticsearch::Client::5_0::Scroll> class and calls L</new()>,
 passing in any arguments.
 
 You can specify a C<scroll> duration (which defaults to C<"1m">) and
 C<scroll_in_qs> (which defaults to C<false>). Any other parameters are
-passed directly to L<Search::Elasticsearch::Client::2_0::Direct/search()>.
+passed directly to L<Search::Elasticsearch::Client::5_0::Direct/search()>.
 
 The C<scroll> duration tells Elasticearch how long it should keep the scroll
 alive.  B<Note>: this duration doesn't need to be long enough to process
@@ -302,7 +262,7 @@ The expiry gets renewed for another C<scroll> period every time new
 a new batch of results is retrieved from the cluster.
 
 By default, the C<scroll_id> is passed as the C<body> to the
-L<scroll|Search::Elasticsearch::Client::2_0::Direct/scroll()> request.
+L<scroll|Search::Elasticsearch::Client::5_0::Direct/scroll()> request.
 To send it in the query string instead, set C<scroll_in_qs> to a true value,
 but be aware: when querying very many indices, the scroll ID can become
 too long for intervening proxies.
@@ -399,21 +359,21 @@ How long the original search plus all subsequent batches took, in milliseconds.
 
 =over
 
-=item * L<Search::Elasticsearch::Client::2_0::Bulk/reindex()>
+=item * L<Search::Elasticsearch::Client::5_0::Direct/search()>
 
-=item * L<Search::Elasticsearch::Client::2_0::Direct/search()>
+=item * L<Search::Elasticsearch::Client::5_0::Direct/scroll()>
 
-=item * L<Search::Elasticsearch::Client::2_0::Direct/scroll()>
+=item * L<Search::Elasticsearch::Client::5_0::Direct/reindex()>
 
 =back
 
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2017 by Elasticsearch BV.
 
 This is free software, licensed under:
 
