@@ -1,11 +1,5 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::2_0::TestServer;
-$Search::Elasticsearch::Client::2_0::TestServer::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::2_0::TestServer::VERSION = '7.301';
+package Search::Elasticsearch::Client::5_0::TestServer;
+$Search::Elasticsearch::Client::5_0::TestServer::VERSION = '6.00';
 use strict;
 use warnings;
 
@@ -18,12 +12,11 @@ sub command_line {
         $ts->es_home . '/bin/elasticsearch',
         '-p',
         $pid_file->filename,
-        map {"-Des.$_"} (
+        map {"-E$_"} (
             'path.data=' . $dir,
             'network.host=127.0.0.1',
             'cluster.name=es_test',
             'discovery.zen.ping_timeout=1s',
-            'discovery.zen.ping.multicast.enabled=false',
             'discovery.zen.ping.unicast.hosts=127.0.0.1:' . $ts->es_port,
             'transport.tcp.port=' . $transport,
             'http.port=' . $http,
@@ -44,19 +37,19 @@ __END__
 
 =head1 NAME
 
-Search::Elasticsearch::Client::2_0::TestServer - Client-specific backend for Search::Elasticsearch::TestServer
+Search::Elasticsearch::Client::5_0::TestServer - Client-specific backend for Search::Elasticsearch::TestServer
 
 =head1 VERSION
 
-version 7.30_1
+version 6.00
 
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2017 by Elasticsearch BV.
 
 This is free software, licensed under:
 
